@@ -129,6 +129,10 @@ ALLOWED_FIELDS  = (
 ###################
 ## ARB Field Dicts
 ###################
+ARB_DEFAULT_FIELDS  = {
+    'testing'         : False
+}
+
 ARB_REQUIRED_FIELDS = ('tran_key',
                        'login')
 
@@ -311,7 +315,12 @@ class RecurringTransaction(Adapter):
         
         if not isinstance(configuration, dict):
             raise ARBException('Configuration must be a dictionary')
-
+        
+        default = ARB_DEFAULT_FIELDS
+        default.update(configuration)
+        
+        configuration = default
+        
         testing = configuration.pop('testing')
         host    = ENDPOINT_ARB_TEST if testing else ENDPOINT_ARB_PRODUCTION
         
